==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: vi\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  ""

]
, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "AS Version"
: ""

, "Useragent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendarfilter"
: ""

, "Contactsfilter"
: ""

, "Emailfilter"
: ""

, "Tasksfilter"
: ""

, "Last Ping"
: ""

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Device, Devices"
: [
  "one:Thiết bị\nother:Thiết bị"

]
, "Devices"
: "Thiết bị"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Chọn 1 thiết bị"

, "No ActiveSync Device registered"
: "Chưa có thiết bị nào được đăng ký"

, "Set as {0} Filter"
: "Đặt như là bộ lọc {0}"

, "Resetted Sync Filter"
: "Khởi tạo lại bộ lọc Sync"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "bộ lọc {0} cho thiết bị \"{1}\" bây giờ là \"{2}\""

, "resetted"
: "đã khởi tạo"

, "Set Sync Filter"
: "Đặt bộ lọc đồng bộ"

, "Default Addressbook"
: "Sổ địa chỉ mặc định"

, "The default addressbook to create new contacts in."
: "Sổ địa chỉ mặc định khi tạo liên lạc mới"

, "Default Calendar"
: "Lịch mặc định"

, "The default calendar to create new events in."
: "Lịch mặc định để tạo sự kiện mới trong đó"

, "Default Task List"
: "Danh sách công việc mặc định"

, "The default task list to create new tasks in."
: "Danh sách công việc mặc định để tạo việc mới trong đó"

, "Default policy for new devices"
: "Chính sách mặc định cho thiết bị mới"

, "Enter the id of the policy to apply to newly created devices."
: "Nhập vào mã chính sách muốn áp dụng mỗi khi thiết bị mới được tạo"

, "Disable Access Log"
: "Tắt nhật ký truy cập"

, "Disable ActiveSync Access Log creation."
: "Ngừng tạo nhật ký truy cập ActiveSync"

, "Filter timeslot for emails"
: ""

, "For how long in the past the emails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: "Chính sách mặc định"

, "Default Policy installed during setup"
: "Chính sách mặc định đã được thiết lập quá trình cài đặt"

, "SyncDevice"
: ""

, "Device"
: "one:Thiết bị\nother:Thiết bị"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Lịch mặc định"

, "The default calendar to create new events in."
: "Lịch mặc định để tạo sự kiện mới trong đó"

, "Default Task List"
: "Danh sách công việc mặc định"

, "The default task list to create new tasks in."
: "Danh sách công việc mặc định để tạo việc mới trong đó"

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""

]
, "Device, Devices"
: [
  "one:Thiết bị\nother:Thiết bị"

]
, "Devices"
: "Thiết bị"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Chọn 1 thiết bị"

, "No ActiveSync Device registered"
: "Chưa có thiết bị nào được đăng ký"

, "Set as {0} Filter"
: "Đặt như là bộ lọc {0}"

, "Resetted Sync Filter"
: "Khởi tạo lại bộ lọc Sync"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "bộ lọc {0} cho thiết bị \"{1}\" bây giờ là \"{2}\""

, "resetted"
: "đã khởi tạo"

, "Set Sync Filter"
: "Đặt bộ lọc đồng bộ"

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: "Chính sách mặc định"

, "Default Policy installed during setup"
: "Chính sách mặc định đã được thiết lập quá trình cài đặt"

, "Default policy for new devices"
: "Chính sách mặc định cho thiết bị mới"

, "Enter the id of the policy to apply to newly created devices."
: "Nhập vào mã chính sách muốn áp dụng mỗi khi thiết bị mới được tạo"

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Tắt nhật ký truy cập"

, "Disable ActiveSync Access Log creation."
: "Ngừng tạo nhật ký truy cập ActiveSync"

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""



, "Sync Device"
: ""

, "Device"
: "one:Thiết bị\nother:Thiết bị"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
